Module

Trait Module 

pub trait Module: Send + Sync {
    // Required methods
    fn kind(&self) -> &'static str;
    fn id(&self) -> &str;
    fn name(&self) -> &str;
    fn load(&mut self) -> Result<(), Error>;
    fn expand_query(
        &self,
        terms: &Vec<Term<'_>>,
        queryparams: &QueryParams,
    ) -> Result<TermExpansions, Error>;
}
This trait is implemented for all query expansions modules

Required Methods

fn kind(&self) -> &'static str

Get the module type

fn id(&self) -> &str

Get the module identifier, some arbititrary short string

fn name(&self) -> &str

Get the module name, a human-readable label

fn load(&mut self) -> Result<(), Error>

Load the module. This MUST be called (once) prior to calling expand_query().

fn expand_query( &self, terms: &Vec<Term<'_>>, queryparams: &QueryParams, ) -> Result<TermExpansions, Error>

Expands a (decomposed) query. Note that load() MUST be called (once) prior to calling this for the first time, otherwise it will result in a panic.

Implementors